==> exo.jcr.component.ftp-1.9.3-sources.jar: org/exoplatform/services/ftp/listcode/FtpUnixL8Coder.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.ftp.listcode;

import org.exoplatform.services.ftp.FtpTextUtils;

/**
 * Created by The eXo Platform SAS
 * Author : Vitaly Guly <gavrik-vetal@ukr.net/mail.ru>
 * @version $Id: $
 */

public class FtpUnixL8Coder implements FtpSystemCoder {

  public String serializeFileInfo(FtpFileInfo fileInfo) {
    String attr = String.format("%srw-------", fileInfo.isCollection() ? "d" : "-");
    String subFolders = "  1";
    String ftpDescr = "eXo      eXo    ";
    String size = FtpTextUtils.getStrachedAtStart(String.format("%s", fileInfo.getSize()), 9);
    String month = fileInfo.getMonth();
    String day = String.format("%d", fileInfo.getDay());
    day = FtpTextUtils.getStrachedAtStart(day, 2);
    String time = fileInfo.getTime();
    String name = fileInfo.getName();
    
    return String.format("%s %s %s %s %s %s %s %s",
        attr, subFolders, ftpDescr,
        size, month, day, time, name);
  }
  
}

==> exo.jcr.component.ftp-1.10.4-sources.jar: org/exoplatform/services/ftp/listcode/FtpUnixL8Coder.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.ftp.listcode;

import org.exoplatform.services.ftp.FtpTextUtils;

/**
 * Created by The eXo Platform SAS Author : Vitaly Guly <gavrik-vetal@ukr.net/mail.ru>
 * 
 * @version $Id: $
 */

public class FtpUnixL8Coder implements FtpSystemCoder {

  public String serializeFileInfo(FtpFileInfo fileInfo) {
    String attr = String.format("%srw-------", fileInfo.isCollection() ? "d" : "-");
    String subFolders = "  1";
    String ftpDescr = "eXo      eXo    ";
    String size = FtpTextUtils.getStrachedAtStart(String.format("%s", fileInfo.getSize()), 9);
    String month = fileInfo.getMonth();
    String day = String.format("%d", fileInfo.getDay());
    day = FtpTextUtils.getStrachedAtStart(day, 2);
    String time = fileInfo.getTime();
    String name = fileInfo.getName();

    return String.format("%s %s %s %s %s %s %s %s",
                         attr,
                         subFolders,
                         ftpDescr,
                         size,
                         month,
                         day,
                         time,
                         name);
  }

}
